@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2012-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2012-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -9,7 +9,7 @@
 #include "abstractimportexportjob.h"
 #include "pimdataexportercore_private_export.h"
 #include <Akonadi/Collection>
-#include <Akonadi/KMime/SpecialMailCollections>
+#include <Akonadi/SpecialMailCollections>
 #include <KArchive>
 #include <QHash>
 #include <QStringList>
@@ -81,7 +81,8 @@ private:
     void mergeSieveTemplate(const KArchiveFile *archivefile, const QString &filename, const QString &prefix);
     void importSimpleFilesInDirectory(const QString &relativePath);
     void copyUnifiedMailBoxConfig(const KSharedConfig::Ptr &archiveConfigOrigin, const KSharedConfig::Ptr &archiveConfigDestination);
-    void importUnifiedMailBoxConfig(const KArchiveFile *archiveconfiguration, const QString &archiveconfigurationrc, const QString &filename, const QString &prefix);
+    void
+    importUnifiedMailBoxConfig(const KArchiveFile *archiveconfiguration, const QString &archiveconfigurationrc, const QString &filename, const QString &prefix);
 
     QHash<QString, QString> mHashResources;
     QStringList mFileList;
